# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_use_public_addresses_for_remote_domains, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  data_type('Optional[String]')

  desc <<-DESC
  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_use_public_addresses_for_remote_domains => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_use_public_addresses_for_remote_domains']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('JTA/%<domain_name>s/UsePublicAddressesForRemoteDomains')
end
