# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:rmi_jdbc_security, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The security protocol used by an RMI client to access a data source. Values are:

  - `Secure`: All incoming JDBC calls require administrator authentication. All other subjects, including anonymous, are rejected. Requires a configured SSL listen port.
  - `Compatibility`: Use an unsecure channel with the application's subject and no check for inbound administrator authentication when using RMI to access a data source. This setting reflects the legacy implementation behavior for RMI access to a data source and is a potential security vulnerability as it provides a client uncontrolled access to a database.

  The default value is `Compatibility`.
  DESC

  data_type("Optional[Variant[Enum['absent','Secure','Compatibility']]]")

  maps_to 'DataSource/%<server_name>s/RmiJDBCSecurity'
end
